@@ -7,7 +7,7 @@ require Exporter;
 
 our ($VERSION, @ISA, @EXPORT, %ZIP_CM_MIN_VERSIONS);
 
-$VERSION = '2.006';
+$VERSION = '2.009';
 
 @ISA = qw(Exporter);
 
@@ -17,6 +17,7 @@ $VERSION = '2.006';
     ZIP_CM_DEFLATE
     ZIP_CM_BZIP2
     ZIP_CM_LZMA
+    ZIP_CM_PPMD
     
     ZIP_LOCAL_HDR_SIG
     ZIP_DATA_HDR_SIG
@@ -31,6 +32,7 @@ $VERSION = '2.006';
     ZIP_GP_FLAG_STREAMING_MASK
     ZIP_GP_FLAG_PATCHED_MASK
     ZIP_GP_FLAG_STRONG_ENCRYPTED_MASK
+    ZIP_GP_FLAG_LZMA_EOS_PRESENT
 
     ZIP_EXTRA_ID_ZIP64
     ZIP_EXTRA_ID_EXT_TIMESTAMP
@@ -51,12 +53,15 @@ use constant ZIP_CM_STORE                      => 0 ;
 use constant ZIP_CM_DEFLATE                    => 8 ;
 use constant ZIP_CM_BZIP2                      => 12 ;
 use constant ZIP_CM_LZMA                       => 14 ; # Not Supported yet
+use constant ZIP_CM_PPMD                       => 98 ; # Not Supported yet
 
 # General Purpose Flag
-use constant ZIP_GP_FLAG_ENCRYPTED_MASK        => 1 ;
-use constant ZIP_GP_FLAG_STREAMING_MASK        => 8 ;
-use constant ZIP_GP_FLAG_PATCHED_MASK          => 32 ;
-use constant ZIP_GP_FLAG_STRONG_ENCRYPTED_MASK => 64 ;
+use constant ZIP_GP_FLAG_ENCRYPTED_MASK        => (1 << 0) ;
+use constant ZIP_GP_FLAG_STREAMING_MASK        => (1 << 3) ;
+use constant ZIP_GP_FLAG_PATCHED_MASK          => (1 << 5) ;
+use constant ZIP_GP_FLAG_STRONG_ENCRYPTED_MASK => (1 << 6) ;
+use constant ZIP_GP_FLAG_LZMA_EOS_PRESENT      => (1 << 1) ;
+use constant ZIP_GP_FLAG_LANGUAGE_ENCODING     => (1 << 11) ;
 
 # Internal File Attributes
 use constant ZIP_IFA_TEXT_MASK                 => 1;
